@@ -70,6 +70,7 @@ class HeSetupContainer extends Component {
         fileGenerator.writeConfigToFile()
             .then(filePath => {
                 self.setup = self.getSetup(filePath)
+                self.setState({ setup: self.setup.start(self.parseOutput, self.processExit) });
             });
     }
 
@@ -86,7 +87,7 @@ class HeSetupContainer extends Component {
     }
 
     componentWillUnmount() {
-        this.props.setup.close();
+        this.setup.close();
         $(ReactDOM.findDOMNode(this)).modal('hide');
     }
 
@@ -99,7 +100,7 @@ class HeSetupContainer extends Component {
 
     passInput(input) {
         if (this.state.question.prompt.length > 0) {
-            this.props.setup.handleInput(input);
+            this.setup.handleInput(input);
             this.resetState()
         }
     }
@@ -156,4 +157,4 @@ class HeSetupContainer extends Component {
     }
 }
 
-export default HeSetupContainer;
\ No newline at end of file
+export default HeSetupContainer;
