@@ -1,8 +1,10 @@
 import React, { Component } from 'react'
 import { checkDns, checkReverseDns } from '../../../helpers/HostedEngineSetupUtil'
 import { getErrorMsgForProperty, validatePropsForUiStage } from '../Validation'
-import { allIntelCpus, amdCpuTypes, configValues, intelCpuTypes, messages, resourceConstants as constants } from '../constants'
+import { allIntelCpus, amdCpuTypes, configValues, defaultInterfaces, intelCpuTypes, messages,
+    resourceConstants, status as gwState } from '../constants'
 import HeWizardVm from './HeWizardVm'
+import { pingGateway } from '../../../helpers/HostedEngineSetupUtil'
 
 const defaultAppliances = [
     { key: "Manually Select", title: "Manually Select" }
@@ -19,11 +21,18 @@ class HeWizardVmContainer extends Component {
             applPathSelection: "",
             appliances: defaultAppliances,
             cpuArch: {},
+            gatewayState: gwState.EMPTY,
+            interfaces: defaultInterfaces,
             errorMsg: "",
             errorMsgs: {},
-            warningMsgs: {}
+            warningMsgs: {},
+            collapsibleSections: {
+                advanced: true
+            }
         };
 
+        this.lastGatewayAddress = "";
+
         this.handleDnsAddressDelete = this.handleDnsAddressDelete.bind(this);
         this.handleDnsAddressUpdate = this.handleDnsAddressUpdate.bind(this);
         this.verifyDns = this.verifyDns.bind(this);
@@ -33,9 +42,11 @@ class HeWizardVmContainer extends Component {
         this.setApplianceFiles = this.setApplianceFiles.bind(this);
         this.setValidationValues = this.setValidationValues.bind(this);
         this.handleVmConfigUpdate = this.handleVmConfigUpdate.bind(this);
+        this.handleCollapsibleSectionChange = this.handleCollapsibleSectionChange.bind(this);
         this.handleApplianceFileUpdate = this.handleApplianceFileUpdate.bind(this);
         this.handleImportApplianceUpdate = this.handleImportApplianceUpdate.bind(this);
         this.setNetworkConfigDisplaySettings = this.setNetworkConfigDisplaySettings.bind(this);
+        this.checkGatewayPingability = this.checkGatewayPingability.bind(this);
         this.validateConfigUpdate = this.validateConfigUpdate.bind(this);
         this.validateRootPasswordMatch = this.validateRootPasswordMatch.bind(this);
         this.validateCpuModelSelection = this.validateCpuModelSelection.bind(this);
@@ -77,8 +88,15 @@ class HeWizardVmContainer extends Component {
 
     setDefaultValues() {
         const heSetupModel = this.state.heSetupModel;
-        const cpuArch = this.props.defaultsProvider.getCpuArchitecture();
+        const defaultsProvider = this.props.defaultsProvider;
 
+        const networkInterfaces = defaultsProvider.getNetworkInterfaces();
+        this.setState({ interfaces: networkInterfaces });
+        heSetupModel.network.bridgeIf.showInReview = networkInterfaces > 1;
+        this.handleVmConfigUpdate("bridgeIf", defaultsProvider.getDefaultInterface(), "network");
+        this.handleVmConfigUpdate("gateway", defaultsProvider.getDefaultGateway(), "network");
+
+        const cpuArch = defaultsProvider.getCpuArchitecture();
         this.setCpuModel(cpuArch, heSetupModel);
         this.setApplianceFiles();
 
@@ -111,10 +129,14 @@ class HeWizardVmContainer extends Component {
         const defaultsProvider = this.props.defaultsProvider;
         const heSetupModel = this.state.heSetupModel;
 
-        heSetupModel.vm.vmVCpus.value = defaultsProvider.getMaxVCpus() > 4 ?
-            4 : defaultsProvider.getMaxVCpus() ;
-        heSetupModel.vm.vmVCpus.range.max = defaultsProvider.getMaxVCpus();
-        heSetupModel.vm.vmMemSizeMB.range.max = defaultsProvider.getMaxMemAvailable();
+        const maxVCpus = defaultsProvider.getMaxVCpus();
+        heSetupModel.vm.vmVCpus.value = maxVCpus > 4 ? 4 : maxVCpus;
+        heSetupModel.vm.vmVCpus.range.max = maxVCpus;
+
+        const maxMemAvail = defaultsProvider.getMaxMemAvailable();
+        const minRecVmMem = resourceConstants.VM_MEM_MIN_RECOMMENDED_MB;
+        heSetupModel.vm.vmMemSizeMB.range.max = maxMemAvail;
+        heSetupModel.vm.vmMemSizeMB.value = maxMemAvail < minRecVmMem ? maxMemAvail : minRecVmMem;
 
         this.setState({ heSetupModel });
     }
@@ -156,6 +178,12 @@ class HeWizardVmContainer extends Component {
         this.setState({ heSetupModel });
     }
 
+    handleCollapsibleSectionChange(sectionName) {
+        const sections = this.state.collapsibleSections;
+        sections[sectionName] = !sections[sectionName];
+        this.setState(sections);
+    }
+
     handleApplianceFileUpdate(value) {
         const heSetupModel = this.state.heSetupModel;
         let showApplPath = this.state.showApplPath;
@@ -197,6 +225,38 @@ class HeWizardVmContainer extends Component {
         this.setState({ model });
     }
 
+    checkGatewayPingability(address) {
+        let errorMsg = this.state.errorMsg;
+        errorMsg = "";
+
+        let errorMsgs = this.state.errorMsgs;
+        errorMsgs.gateway = "";
+
+        let gatewayState = this.state.gatewayState;
+        gatewayState = gwState.POLLING;
+
+        this.setState({ gatewayState, errorMsg, errorMsgs });
+
+        this.lastGatewayAddress = address;
+
+        let self = this;
+        pingGateway(address)
+            .done(function() {
+                if (address === self.lastGatewayAddress) {
+                    gatewayState = gwState.SUCCESS;
+                    self.setState({errorMsg, gatewayState});
+                }
+            })
+            .fail(function() {
+                if (address === self.lastGatewayAddress) {
+                    errorMsg = messages.GENERAL_ERROR_MSG;
+                    errorMsgs.gateway = messages.IP_NOT_PINGABLE;
+                    gatewayState = gwState.FAILURE;
+                    self.setState({errorMsg, errorMsgs, gatewayState});
+                }
+            });
+    }
+
     validateConfigUpdate(propName, config) {
         let errorMsg = this.state.errorMsg;
         const errorMsgs = {};
@@ -217,6 +277,10 @@ class HeWizardVmContainer extends Component {
             this.validateCpuModelSelection(errorMsgs);
         }
 
+        if (propName === "gateway" && propErrorMsg === "") {
+            this.checkGatewayPingability(prop.value);
+        }
+
         this.setState({ errorMsg, errorMsgs });
     }
 
@@ -268,7 +332,8 @@ class HeWizardVmContainer extends Component {
     validateAllInputs() {
         let errorMsg = "";
         let errorMsgs = {};
-        let propsAreValid = validatePropsForUiStage("VM", this.state.heSetupModel, errorMsgs);
+        let propsAreValid = validatePropsForUiStage("VM", this.state.heSetupModel, errorMsgs) ||
+            this.state.gatewayState === gwState.FAILURE;
         let passwordsMatch = this.validateRootPasswordMatch(errorMsgs);
 
         if (!propsAreValid || !passwordsMatch) {
@@ -280,7 +345,6 @@ class HeWizardVmContainer extends Component {
     }
 
     shouldComponentUpdate(nextProps, nextState){
-
         if(!this.props.validating && nextProps.validating){
             this.props.validationCallBack(this.validateAllInputs())
         }
@@ -297,14 +361,18 @@ class HeWizardVmContainer extends Component {
             <HeWizardVm
                 appliances={this.state.appliances}
                 applPathSelection={this.state.applPathSelection}
+                collapsibleSections={this.state.collapsibleSections}
                 cpuArch={this.state.cpuArch}
                 deploymentType={this.props.deploymentType}
                 errorMsg={this.state.errorMsg}
                 errorMsgs={this.state.errorMsgs}
+                gatewayState={this.state.gatewayState}
+                interfaces={this.state.interfaces}
                 handleDnsAddressUpdate={this.handleDnsAddressUpdate}
                 handleDnsAddressDelete={this.handleDnsAddressDelete}
                 handleImportApplianceUpdate={this.handleImportApplianceUpdate}
                 handleVmConfigUpdate={this.handleVmConfigUpdate}
+                handleCollapsibleSectionChange={this.handleCollapsibleSectionChange}
                 heSetupModel={this.state.heSetupModel}
                 importAppliance={this.state.importAppliance}
                 showApplPath={this.state.showApplPath}
