@@ -14,18 +14,6 @@ class AnsibleVarFilesGenerator {
 
     checkValue(propName, value) {
         let retVal = value;
-        if (propName === "storageDomainConnection" || propName === "storage") {
-            switch (this.model.storage.domainType.value.toLowerCase()) {
-                case "iscsi":
-                    retVal = this.model.storage.LunID.value;
-                    break;
-                case "fc":
-                    retVal = "";
-                    break;
-                default:
-                    break;
-            }
-        }
 
         if (propName === "domainType" && value.includes("nfs")) {
             retVal = "nfs";
@@ -35,11 +23,6 @@ class AnsibleVarFilesGenerator {
             retVal = "";
         }
 
-        if (propName === "cloudinitVMStaticCIDR") {
-            const prefix = this.model.vm.cloudinitVMStaticCIDRPrefix.value;
-            retVal = value + "/" + prefix;
-        }
-
         return retVal;
     }
 
@@ -121,4 +104,4 @@ class AnsibleVarFilesGenerator {
     }
 }
 
-export default AnsibleVarFilesGenerator;
\ No newline at end of file
+export default AnsibleVarFilesGenerator;
