@@ -47,7 +47,7 @@ module.exports = {
       {from: 'static/index.html'},
       {from: 'static/app.css'},
       {from: 'static/gdeploy-templates', to: 'gdeploy-templates'},
-      {from: 'static/hostedEngineAnsibleFiles', to: 'hostedEngineAnsibleFiles'},
+      {from: 'static/hostedEngineAnsibleFiles', to: 'hostedEngineAnsibleFiles'}
     ])
   ]
 };
